@@ -21,10 +21,12 @@ import (
 	"encoding/json"
 	"fmt"
 	"html/template"
+	"os"
 	"os/exec"
 	"path"
 	"strings"
 
+	"github.com/blang/semver/v4"
 	"github.com/pkg/errors"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/minikube/command"
@@ -337,3 +339,22 @@ func addRepoTagToImageName(imgName string) string {
 	} // else it already has repo name dont add anything
 	return imgName
 }
+
+// kubeletCRIOptions returns the container runtime options for the kubelet
+func kubeletCRIOptions(cr Manager, kubernetesVersion semver.Version) map[string]string {
+	opts := map[string]string{
+		"container-runtime-endpoint": fmt.Sprintf("unix://%s", cr.SocketPath()),
+	}
+	if kubernetesVersion.LT(semver.MustParse("1.24.0-alpha.0")) {
+		opts["container-runtime"] = "remote"
+	}
+	return opts
+}
+
+func checkCNIPlugins(kubernetesVersion semver.Version) error {
+	if kubernetesVersion.LT(semver.Version{Major: 1, Minor: 24}) {
+		return nil
+	}
+	_, err := os.Stat("/opt/cni/bin")
+	return err
+}
