@@ -307,15 +307,13 @@ func postStartSetup(h *host.Host, mc config.ClusterConfig) error {
 		return nil
 	}
 
-	// If none driver with docker container-runtime, require cri-dockerd and dockerd.
-	if driver.IsNone(h.DriverName) && mc.KubernetesConfig.ContainerRuntime == constants.Docker {
-		// If Kubernetes version >= 1.24, require both cri-dockerd and dockerd.
-		k8sVer, err := semver.ParseTolerant(mc.KubernetesConfig.KubernetesVersion)
-		if err != nil {
-			klog.Errorf("unable to parse Kubernetes version: %s", mc.KubernetesConfig.KubernetesVersion)
-			return err
-		}
-		if k8sVer.GTE(semver.Version{Major: 1, Minor: 24}) {
+	k8sVer, err := semver.ParseTolerant(mc.KubernetesConfig.KubernetesVersion)
+	if err != nil {
+		klog.Errorf("unable to parse Kubernetes version: %s", mc.KubernetesConfig.KubernetesVersion)
+		return err
+	}
+	if driver.IsNone(h.DriverName) && k8sVer.GTE(semver.Version{Major: 1, Minor: 24}) {
+		if mc.KubernetesConfig.ContainerRuntime == constants.Docker {
 			if _, err := exec.LookPath("cri-dockerd"); err != nil {
 				exit.Message(reason.NotFoundCriDockerd, "\n\n")
 			}
@@ -323,6 +321,9 @@ func postStartSetup(h *host.Host, mc config.ClusterConfig) error {
 				exit.Message(reason.NotFoundDockerd, "\n\n")
 			}
 		}
+		if _, err := os.Stat("/opt/cni/bin"); err != nil {
+			exit.Message(reason.NotFoundCNIPlugins, "\n\n")
+		}
 	}
 
 	klog.Infof("creating required directories: %v", requiredDirectories)
